@@ -1,3 +1,8 @@
+'''
+Created on Mar. 16, 2023
+
+@author: wearo
+'''
 class Calc:
     def __init__(self, a, b):
         self.a = a
